dart_datakit library

Classes

Aggregations
Provides aggregation operations.
Converters
Utility functions for type conversion and CSV parsing.
Datacat
A versatile data structure resembling a DataFrame. It holds column names and rows of data and can optionally enforce a schema. It also provides static methods to create nested Datacats from JSON.
DatacatSchema
Defines the required structure (schema) for a Datacat. Each key in requiredColumns represents a column name, and its value is the required Type (or null if no type check is needed). If strictColumns is true, the Datacat must not contain any extra columns.
IO
I/O utilities for reading and writing CSV, JSON, and Excel files.
Joins
Provides join operations between Datacat objects.
Pivots
Provides pivot Datacat functionality.
Transformations
Provides data transformation functions.
Validators
Utility functions for data validation.
WindowFunctions
Provides window (rolling) functions.