Aggregations class

Provides aggregation operations.

Constructors

Aggregations()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

mean(Datacat datacat, String columnName) double
Computes the mean of a numeric column.
sum(Datacat datacat, String columnName) num
Computes the sum of a numeric column.