IO class
I/O utilities for reading and writing CSV, JSON, and Excel files.
Constructors
- IO()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
readCsvAsDatacat(
String path) → Future< Datacat> - Reads a CSV file and returns a Datacat.
-
readExcelAsDatacat(
String path) → Future< Datacat> - Reads an Excel file and returns a Datacat for the first sheet.
-
readFile(
String path) → Future< String> - Reads a file and returns its content as a string.
-
readJsonAsDatacat(
String path) → Future< Datacat> - Reads a JSON file and returns a Datacat.
-
writeDatacatAsCsv(
String path, Datacat datacat) → Future< void> - Writes a Datacat to a CSV file.
-
writeDatacatAsExcel(
String path, Datacat datacat) → Future< void> - Writes a Datacat to an Excel file.
-
writeFile(
String path, String content) → Future< void> -
Writes
contentto a file atpath.