Pivots class

Provides pivot Datacat functionality.

Constructors

Pivots()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

pivot(Datacat datacat, String indexColumn, String pivotColumn, String valueColumn) Datacat
Creates a pivot Datacat from datacat using indexColumn for rows, pivotColumn for new column headers, and valueColumn for values. Aggregates values using sum.