DatacatSchema class
Defines the required structure (schema) for a Datacat. Each key in requiredColumns represents a column name, and its value is the required Type (or null if no type check is needed). If strictColumns is true, the Datacat must not contain any extra columns.
Constructors
-
DatacatSchema({required Map<
String, Type?> requiredColumns, bool strictColumns = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requiredColumns
→ Map<
String, Type?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strictColumns → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited